odbc
pub struct Cursor<'a, 'b: 'a> { /* fields omitted */ }
Used to retrieve data from the fields of a query resul
impl<'a, 'b> Cursor<'a, 'b>
fn get_data<T>(&mut self, col_or_param_num: u16) -> Result<Option<T>> where T: Output
Retrieves data for a single column in the result set